
#ifndef _C15_ce700_
#define _C15_ce700_

#ifdef __cplusplus
extern "C" {
#endif

extern EIF_INTEGER_32 F104_1249(EIF_REFERENCE);
extern void F104_1250(EIF_REFERENCE, EIF_INTEGER_32);
extern void EIF_Minit700(void);

#ifdef __cplusplus
}
#endif

#endif
